@@ -397,13 +397,6 @@ void init(int argc, char **argv)
 	char *tmp;
 	char *cfg_pidfile = NULL;
 
-	if (1<<INTBITS != sizeof(int)*8) {
-		fprintf(stderr,
-			"Error: wrong architecture. Recompile so that sizeof(int)=%d\n",
-			(int)(sizeof(int)*8));
-		exit(1);
-	}
-
 	/*
 	 * Initialize the previously static variables.
 	 */
@@ -902,11 +895,6 @@ int main(int argc, char **argv)
 	signal(SIGTTOU, sig_pause);
 	signal(SIGTTIN, sig_listen);
 
-	if (global.mode & MODE_DAEMON) {
-		global.mode &= ~MODE_VERBOSE;
-		global.mode |= MODE_QUIET;
-	}
-
 	/* MODE_QUIET can inhibit alerts and warnings below this line */
 
 	global.mode &= ~MODE_STARTING;
@@ -1068,10 +1056,11 @@ int main(int argc, char **argv)
 		 * it would have already be done, and 0-2 would have been affected to listening
 		 * sockets
 		 */
-		if (!(global.mode & MODE_QUIET)) {
+		if (!(global.mode & MODE_QUIET) || (global.mode & MODE_VERBOSE)) {
 			/* detach from the tty */
 			fclose(stdin); fclose(stdout); fclose(stderr);
 			close(0); close(1); close(2); /* close all fd's */
+			global.mode &= ~MODE_VERBOSE;
 			global.mode |= MODE_QUIET; /* ensure that we won't say anything from now */
 		}
 		pid = getpid(); /* update child's pid */
