@@ -314,7 +314,7 @@ void maintain_proxies(struct timeval *next)
 	/* if there are enough free sessions, we'll activate proxies */
 	if (actconn < global.maxconn) {
 		while (p) {
-			if (p->feconn < p->maxconn) {
+			if (!p->maxconn || p->feconn < p->maxconn) {
 				if (p->state == PR_STIDLE) {
 					for (l = p->listen; l != NULL; l = l->next)
 						enable_listener(l);
@@ -351,15 +351,7 @@ void maintain_proxies(struct timeval *next)
 				if (t == 0) {
 					Warning("Proxy %s stopped.\n", p->id);
 					send_log(p, LOG_WARNING, "Proxy %s stopped.\n", p->id);
-
-					for (l = p->listen; l != NULL; l = l->next) {
-						unbind_listener(l);
-						if (l->state >= LI_ASSIGNED) {
-							delete_listener(l);
-							listeners--;
-						}
-					}
-					p->state = PR_STSTOPPED;
+					stop_proxy(p);
 					/* try to free more memory */
 					pool_gc2();
 				}
@@ -388,8 +380,8 @@ void soft_stop(void)
 	tv_now(&now); /* else, the old time before select will be used */
 	while (p) {
 		if (p->state != PR_STSTOPPED) {
-			Warning("Stopping proxy %s in %d ms.\n", p->id, p->grace);
-			send_log(p, LOG_WARNING, "Stopping proxy %s in %d ms.\n", p->id, p->grace);
+			Warning("Stopping %s %s in %d ms.\n", proxy_cap_str(p->cap), p->id, p->grace);
+			send_log(p, LOG_WARNING, "Stopping %s %s in %d ms.\n", proxy_cap_str(p->cap), p->id, p->grace);
 			tv_ms_add(&p->stop_time, &now, p->grace);
 		}
 		p = p->next;
@@ -421,6 +413,28 @@ void pause_proxy(struct proxy *p)
 	}
 }
 
+
+/*
+ * This function completely stops a proxy and releases its listeners. It has
+ * to be called when going down in order to release the ports so that another
+ * process may bind to them. It must also be called on disabled proxies at the
+ * end of start-up. When all listeners are closed, the proxy is set to the
+ * PR_STSTOPPED state.
+ */
+void stop_proxy(struct proxy *p)
+{
+	struct listener *l;
+
+	for (l = p->listen; l != NULL; l = l->next) {
+		unbind_listener(l);
+		if (l->state >= LI_ASSIGNED) {
+			delete_listener(l);
+			listeners--;
+		}
+	}
+	p->state = PR_STSTOPPED;
+}
+
 /*
  * This function temporarily disables listening so that another new instance
  * can start listening. It is designed to be called upon reception of a
@@ -436,16 +450,17 @@ void pause_proxies(void)
 	p = proxy;
 	tv_now(&now); /* else, the old time before select will be used */
 	while (p) {
-		if (p->state != PR_STERROR &&
+		if (p->cap & PR_CAP_FE &&
+		    p->state != PR_STERROR &&
 		    p->state != PR_STSTOPPED &&
 		    p->state != PR_STPAUSED) {
-			Warning("Pausing proxy %s.\n", p->id);
-			send_log(p, LOG_WARNING, "Pausing proxy %s.\n", p->id);
+			Warning("Pausing %s %s.\n", proxy_cap_str(p->cap), p->id);
+			send_log(p, LOG_WARNING, "Pausing %s %s.\n", proxy_cap_str(p->cap), p->id);
 			pause_proxy(p);
 			if (p->state != PR_STPAUSED) {
 				err |= 1;
-				Warning("Proxy %s failed to enter pause mode.\n", p->id);
-				send_log(p, LOG_WARNING, "Proxy %s failed to enter pause mode.\n", p->id);
+				Warning("%s %s failed to enter pause mode.\n", proxy_cap_str(p->cap), p->id);
+				send_log(p, LOG_WARNING, "%s %s failed to enter pause mode.\n", proxy_cap_str(p->cap), p->id);
 			}
 		}
 		p = p->next;
@@ -472,8 +487,8 @@ void listen_proxies(void)
 	tv_now(&now); /* else, the old time before select will be used */
 	while (p) {
 		if (p->state == PR_STPAUSED) {
-			Warning("Enabling proxy %s.\n", p->id);
-			send_log(p, LOG_WARNING, "Enabling proxy %s.\n", p->id);
+			Warning("Enabling %s %s.\n", proxy_cap_str(p->cap), p->id);
+			send_log(p, LOG_WARNING, "Enabling %s %s.\n", proxy_cap_str(p->cap), p->id);
 
 			for (l = p->listen; l != NULL; l = l->next) {
 				if (listen(l->fd, p->backlog ? p->backlog : p->maxconn) == 0) {
@@ -491,10 +506,10 @@ void listen_proxies(void)
 					else
 						port = ntohs(((struct sockaddr_in *)(&l->addr))->sin_port);
 
-					Warning("Port %d busy while trying to enable proxy %s.\n",
-						port, p->id);
-					send_log(p, LOG_WARNING, "Port %d busy while trying to enable proxy %s.\n",
-						 port, p->id);
+					Warning("Port %d busy while trying to enable %s %s.\n",
+						port, proxy_cap_str(p->cap), p->id);
+					send_log(p, LOG_WARNING, "Port %d busy while trying to enable %s %s.\n",
+						 port, proxy_cap_str(p->cap), p->id);
 					/* Another port might have been enabled. Let's stop everything. */
 					pause_proxy(p);
 					break;
